# [0.7.0](https://github.com/AsifArmanRahman/firebase-rest-api/compare/v0.6.0...v0.7.0) (2022-07-24)


### Features

* **auth:** add _𝘵𝘰𝘬𝘦𝘯_𝘧𝘳𝘰𝘮_𝘢𝘶𝘵𝘩_𝘶𝘳𝘭 method ([e444135](https://github.com/AsifArmanRahman/firebase-rest-api/commit/e444135a9d1107383405717029ccd0aab82f1f70))
* **auth:** Sign In with Google ([be6cb05](https://github.com/AsifArmanRahman/firebase-rest-api/commit/be6cb0551fc271cb3ae818de6f06137bbf44139d))



# [0.6.0](https://github.com/AsifArmanRahman/firebase-rest-api/compare/v0.5.0...v0.6.0) (2022-07-24)


### Features

* **auth:** add 𝘴𝘪𝘨𝘯_𝘪𝘯_𝘸𝘪𝘵𝘩_𝘰𝘢𝘶𝘵𝘩_𝘤𝘳𝘦𝘥𝘦𝘯𝘵𝘪𝘢𝘭 ([ad211a5](https://github.com/AsifArmanRahman/firebase-rest-api/commit/ad211a5bc3c9deddbe8441ff524d0008e0eb19a7))
* **auth:** client secret from file ([e5ea84e](https://github.com/AsifArmanRahman/firebase-rest-api/commit/e5ea84ed1a54246fe5a0709b7eafaaf7dd0aeb2c))



# [0.5.0](https://github.com/AsifArmanRahman/firebase-rest-api/compare/v0.4.9...v0.5.0) (2022-07-23)


### Features

* **auth:** add 𝘤𝘳𝘦𝘢𝘵𝘦_𝘢𝘶𝘵𝘩𝘦𝘯𝘵𝘪𝘤𝘢𝘵𝘪𝘰𝘯_𝘶𝘳𝘪 method ([b45a7f2](https://github.com/AsifArmanRahman/firebase-rest-api/commit/b45a7f203b0e4369bd501831ffca9f26c3eac464))



## [0.4.9](https://github.com/AsifArmanRahman/firebase-rest-api/compare/v0.4.8...v0.4.9) (2022-07-22)


### Bug Fixes

* **storage:** proper link generate with 𝘨𝘦𝘵_𝘶𝘳𝘭 ([c825c16](https://github.com/AsifArmanRahman/firebase-rest-api/commit/c825c1695f4a0e87d4daa467c2ca654a9cc05248))


### Performance Improvements

* **storage:** use 𝘳𝘦𝘲𝘶𝘦𝘴𝘵 param ([f51d0dc](https://github.com/AsifArmanRahman/firebase-rest-api/commit/f51d0dc52e030bfe867d70c7728c3ccc32dc4334))



## [0.4.8](https://github.com/AsifArmanRahman/firebase-rest-api/compare/v0.4.7...v0.4.8) (2022-07-21)


### Bug Fixes

* **storage:** set path via 𝘤𝘩𝘪𝘭𝘥 for 𝘥𝘦𝘭𝘦𝘵𝘦 ([b0527f0](https://github.com/AsifArmanRahman/firebase-rest-api/commit/b0527f0d418ad203df5845e1fd123bafe88a4b5d))



## [0.4.7](https://github.com/AsifArmanRahman/firebase-rest-api/compare/v0.4.6...v0.4.7) (2022-07-21)


### Bug Fixes

* **storage:** set path via 𝘤𝘩𝘪𝘭𝘥 for 𝘥𝘰𝘸𝘯𝘭𝘰𝘢𝘥 ([da4d1de](https://github.com/AsifArmanRahman/firebase-rest-api/commit/da4d1deb9cfcc3c962f0240b70f9fee284dcd3e6))



## [0.4.6](https://github.com/AsifArmanRahman/firebase-rest-api/compare/v0.4.5...v0.4.6) (2022-07-20)


### Bug Fixes

* custom token generator ( [#1](https://github.com/AsifArmanRahman/firebase-rest-api/issues/1)  ) ([b4cb169](https://github.com/AsifArmanRahman/firebase-rest-api/commit/b4cb1699d2d48d9741311d04a8530bf0242811e2))



## [0.4.5](https://github.com/AsifArmanRahman/firebase-rest-api/compare/d0837260dcbc5ed4b890f38ac36b5dfa10d05e48...v0.4.5) (2022-07-19)


### Bug Fixes

* **Build:** update requests version ([d083726](https://github.com/AsifArmanRahman/firebase-rest-api/commit/d0837260dcbc5ed4b890f38ac36b5dfa10d05e48))


### Performance Improvements

* use 𝘳𝘦𝘲𝘶𝘦𝘴𝘵 param ([db224f1](https://github.com/AsifArmanRahman/firebase-rest-api/commit/db224f1b75d57f77a8b118e6ed52ac22313e4fbf))



